this.name        = "targetAutolock";
this.author      = "Thargoid";
this.license     = "CC BY-NC-SA 3.0";
this.description = "Automatic target locking to attacking ships.";
this.version     = "1.13";

this.$installed = false;
this.$oldTarget = null;
this.$scanColor1 = "cyanColor";
this.$scanColor2 = "grayColor";
this.$targetTimer;
//
// Event Handlers
//

//---------------------------------------------------------------------------------
this.startUp = function _tap_startUp() {
    this.$oldTarget = null;
    this.$scanColor1 = "cyanColor";
    this.$scanColor2 = "grayColor";
}

//---------------------------------------------------------------------------------
this.startUpComplete = this.playerBoughtNewShip = this.playerReplacedShip = this.$newShip = function _tap_newShip() {
    this.ship = player.ship;
    if (this.ship.equipmentStatus("EQ_TARGET_AUTOLOCK") === "EQUIPMENT_OK")
        this.$installed = true;
    else if (missionVariables.targetAutolock != null) {
        if (missionVariables.targetAutolock === "TRUE") 
            this.ship.awardEquipment("EQ_TARGET_AUTOLOCK");
        else
            this.$installed = false;
    }
    if (missionVariables.targetAutolock) delete missionVariables.targetAutolock;
}

//---------------------------------------------------------------------------------
this.equipmentAdded = function _tap_equipmentAdded(equipmentKey) {
    if (equipmentKey === "EQ_TARGET_AUTOLOCK") this.$installed = true;
}

//---------------------------------------------------------------------------------
this.equipmentRemoved = function _tap_equipmentRemoved(equipmentKey) {
    if (equipmentKey === "EQ_TARGET_AUTOLOCK") {
        this.$installed = false;
        this.$reset();
    } else if (equipmentKey === "EQ_SCANNER_SHOW_MISSILE_TARGET" && 
                this.$targetTimer && this.$targetTimer.isRunning)
        this.$reset();
    
}

//---------------------------------------------------------------------------------
this.shipDied = this.shipWillEnterWitchspace = this.$reset = function _tap_reset() {
    var oldTarget = this.$oldTarget;

    if (this.$targetTimer && this.$targetTimer.isRunning)
        this.$targetTimer.stop();

    if (oldTarget) {
        oldTarget.scannerDisplayColor1 = null;
        oldTarget.scannerDisplayColor2 = null;
    }
    this.$oldTarget = null;    
}

//---------------------------------------------------------------------------------
this.shipDockedWithStation = function _tap_shipDockedWithStation(station) {    
    if (this.$installed) this.$reset();
}    

//---------------------------------------------------------------------------------
this.shipTargetAcquired = function _tap_newTarget(newTarget) {
    if (!this.$installed || 
        this.ship.equipmentStatus("EQ_SCANNER_SHOW_MISSILE_TARGET") !== "EQUIPMENT_OK")
        return;
    
    if (!this.$targetTimer)
        this.$targetTimer = new Timer(this, this.$lockOn, 0, 0.25);
    else if (!this.$targetTimer.isRunning)
        this.$targetTimer.start();
}
    
//---------------------------------------------------------------------------------
this.shipTargetLost = this.shipTargetDestroyed = function _tap_lostTarget(lostTarget) {
    if (this.$installed && 
        this.ship.equipmentStatus("EQ_SCANNER_SHOW_MISSILE_TARGET") === "EQUIPMENT_OK") i
        this.$reset();
}    
    
//---------------------------------------------------------------------------------
this.shipBeingAttacked = function _tap_shipBeingAttacked(attacker) {
    var _player = player;
    var pship = _player.ship;

    if (this.$installed && 
        pship.equipmentStatus("EQ_SCANNER_SHOW_MISSILE_TARGET") === "EQUIPMENT_OK" && 
        pship.target == null && 
        attacker && !attacker.isCloaked && 
        !attacker.hasRole("OXP_stealthShip") && 
        !attacker.hasRole("OXP_noAutolock") && 
        !attacker.hasRole("TAP_noAutolock")) {
        pship.target = attacker;
        _player.commsMessage("Auto-locked onto attacker - " + attacker.displayName + ".", 5);
    }
}

//
// Internal Functions
//

//---------------------------------------------------------------------------------
this.$lockOn = function _tap_lockOn() {
    var pship = this.ship;
    var ptarget = ship.target;

    if (this.$oldTarget && !this.$oldTarget.isValid)
        this.$oldTarget = null;
        
    if (!ptarget || ptarget == pship) {
        pship.target = null;
        this.$reset();
        return;
    }

    if (this.$oldTarget && this.$oldTarget != ptarget) {
        this.$oldTarget.scannerDisplayColor1 = null;
        this.$oldTarget.scannerDisplayColor2 = null;
    } 

    if (this.$oldTarget && ptarget == this.$oldTarget && 
        ptarget.scannerDisplayColor1 == this.$scanColor1 && 
        ptarget.scannerDisplayColor2 == this.$scanColor2)
        return;
        
    if (ptarget) {        
        this.$oldTarget = ptarget;
        ptarget.scannerDisplayColor1 = this.$scanColor1;
        ptarget.scannerDisplayColor2 = this.$scanColor2;
    }
}

